% nbt_DFA(NumChannels) - Creates a DFA biomarker object for 'NumSubjects' number of
% subjects
%
% Usage:
%   >>  DFAobject = DFA( NumSubjects, NumChannels);
%
% Inputs:
%   NumChannels - Number of Channels
%
% Outputs:
%   DFAobject     - DFA Biomarker object
%
% Example:
%
% References:
%
%
% See also:
% NBT_SCALING_DFA

%------------------------------------------------------------------------------------
% Originally created by Simon-Shlomo Poil (2008), see NBT website (http://www.nbtwiki.net) for current email address
%------------------------------------------------------------------------------------
%
% ChangeLog - see version control log at NBT website for details.
%
% Copyright (C) 2008 Simon-Shlomo Poil  (Neuronal Oscillations and Cognition group,
% Department of Integrative Neurophysiology, Center for Neurogenomics and Cognitive Research,
% Neuroscience Campus Amsterdam, VU University Amsterdam)
%
% Part of the Neurophysiological Biomarker Toolbox (NBT)
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
%
% See Readme.txt for additional copyright information.
% -

classdef nbt_DFA
    properties
        
        MarkerValues % the biomarker values
        NumChannels % number of channels
        Fs % The sampling frequency
        DateLastUpdate %last date this biomarker was updated
        PrimaryBiomarker % the primary biomarker to use in scripts
        Biomarkers % list of all biomarkers in the object
        BiomarkerUnits %list of biomarker units
        ReseacherID % ID of the Reseacher or script that made the last update
        ProjectID % The ID of the project which the biomarker belongs to
        SubjectID % The ID of the subject
        FrequencyRange %Frequency range of processed signal [] means broadband.
        Condition % The condition ID

        DFA_y
        DFA_x
        FitInterval
        CalcInterval
        Overlap
        res_logbin
    end
    methods
        function DFAobject= nbt_DFA(NumChannels)
            if nargin == 0
                NumChannels = 1;
            end
            %% Define DFA_x and DFA_y fields
            DFAobject.DFA_y  = cell(NumChannels, 1);
            DFAobject.DFA_x  = [];
            %% Define DFA exponent field
            DFAobject.MarkerValues = nan(NumChannels, 1);
            %% Define fields for additional information
            DFAobject.PrimaryBiomarker = 'MarkerValues';
            DFAobject.Biomarkers = {'MarkerValues'};
            DFAobject.FitInterval = nan(2,1);
            DFAobject.CalcInterval = nan(2,1);
            DFAobject.Overlap = NaN;
            DFAobject.Condition = NaN;
            DFAobject.DateLastUpdate = NaN;
            DFAobject.Fs = NaN;
            DFAobject.res_logbin = 10;
        end
    end
end